This issue tracker is **ONLY** used for reporting bugs with __topggpy__. Feel free to share your suggestions in the #api channel in our [Discord server](https://discord.gg/EYHTgJX)!

For help with general Python issues, use [StackOverflow](https://stackoverflow.com), our [#development channel](https://discord.gg/EYHTgJX), or the [Python Discord server](https://discord.gg/python).


<!--- Provide a general summary of the issue in the title above. -->

## Expected Behavior
<!--- Tell us what should happen. -->

## Current Behavior
<!--- Tell us what happens instead of the expected behavior. -->

## Development Environment
<!--- What is your Python version, module (topggpy) version, and OS? -->

## Steps to Reproduce
<!--- Provide a live example or an unambiguous set of steps to reproduce this bug. -->
<!--- Include code to reproduce, if relevant. -->
1.
2.
3.
4.

<!--- OPTIONAL STUFF BELOW -->

## Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

## Possible Solution
<!--- Suggest a fix/reason for the bug (if applicable). -->

## Detailed Description
<!--- Provide a detailed description of the change or addition you are proposing. -->

## Possible Implementation
<!--- Provide details on how your addition or change could be implemented -->
